ISO20022.Camt053.Entry (ISO20022 v0.1.0)

Copy Markdown View Source

A single booked transaction entry from <Ntry>.

amount is always positive. Direction is conveyed by credit_debit. reversal being true indicates this entry cancels a previously booked entry — the credit_debit indicator already reflects the net effect of the reversal.

Summary

Types

credit_debit()

@type credit_debit() :: :credit | :debit

t()

@type t() :: %ISO20022.Camt053.Entry{
  account_servicer_ref: String.t() | nil,
  additional_info: String.t() | nil,
  amount: Decimal.t(),
  bank_transaction_code: ISO20022.Camt053.BankTxCode.t() | nil,
  booking_date: Date.t() | nil,
  credit_debit: credit_debit(),
  currency: String.t(),
  details: [ISO20022.Camt053.EntryDetails.t()],
  ref: String.t(),
  reversal: boolean(),
  status: :booked,
  value_date: Date.t() | nil
}